## **DEDICATION**

---

_"This project is dedicated to my cousin who was like a mother to me. Though you are no longer with us, you will never be forgotten. May your memory be forever held in this project."_  
-- **Bridget Trinity Vedjesu** --

<br>

<div align="center">
<img src="https://github.com/cleragui/pypi/blob/main/image/logo-with-name.png?raw=true">
</div>

## **Clera - GUI Development with Python**

---

Clera provides platform for developing python GUI quickly and simply with low learning curve.

<br>

## **THE BASICS**

### **Installation**

```bash
pip install clera
```

Your first application and Skeleton of every GUI developed using clera.

**Code:**

```python
from clera import *
window = Window()
# window widgets and layouts goes here!
window.run()
```

**Output:**

![Window](https://github.com/cleragui/pypi/blob/main/image/window.png?raw=true)

> **" Why Complicate Simplicity? "**

<br>

## **PLATFORMS**

> Clera runs on multiple platforms and has a native interface on each.

### **Hardware Support**

- Runs on Desktop and Laptops

### **OS Support**

- Windows
- Mac
- Linux

<br>

> INFO: Visit https://cleragui.github.io/ for documentation and more information.

<br>

---
